Struct
QmiMessageLocSetOperationModeInput
since: 1.22
Description [src]
struct QmiMessageLocSetOperationModeInput {
/* No available fields */
}
The QmiMessageLocSetOperationModeInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.22
Constructors
qmi_message_loc_set_operation_mode_input_new
Allocates a new QmiMessageLocSetOperationModeInput.
since: 1.22
Instance methods
qmi_message_loc_set_operation_mode_input_get_operation_mode
Get the ‘Operation Mode’ field from self.
since: 1.22
qmi_message_loc_set_operation_mode_input_ref
Atomically increments the reference count of self by one.
since: 1.22
qmi_message_loc_set_operation_mode_input_set_operation_mode
Set the ‘Operation Mode’ field in the message.
since: 1.22
qmi_message_loc_set_operation_mode_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.22